@@ -1,6 +1,5 @@
 #' @keywords internal
-MakeBibLaTeX <- function(docstyle = "text", authortitle = FALSE) local({
-docstyle <- get("docstyle", parent.frame(2))
+MakeBibLaTeX <- function(docstyle = "text", authortitle = FALSE) {
 ##################################################################
 ## Formatting functions
 
@@ -42,37 +41,6 @@ fmtNumPre <- function(doc){
   res
 }
 
-cleanupLatex <- function (x){
-    if (!length(x))
-        return(x)
-
-    if (any(grepl('mkbib', x, useBytes = TRUE))){
-      x <- gsub('mkbibquote', 'dQuote', x, useBytes = TRUE)
-      x <- gsub('mkbibemph', 'emph', x, useBytes = TRUE)
-      x <- gsub('mkbibbold', 'bold', x, useBytes = TRUE)
-    }
-    x <- gsub('\\\\hyphen', '-', x, useBytes = TRUE)
-
-    latex <- try(tools::parseLatex(x), silent = TRUE)
-    if (inherits(latex, "try-error")) {
-        x
-    }else {
-        x <- tools::deparseLatex(tools::latexToUtf8(latex), dropBraces = TRUE)
-        if (grepl("\\\\[[:punct:]]", x, useBytes = TRUE)){
-          x <- gsub("\\\\'I", '\u00cd', x, useBytes = TRUE)
-          x <- gsub("\\\\'i", '\u00ed', x, useBytes = TRUE)
-          x <- gsub('\\\\"I', '\u00cf', x, useBytes = TRUE)
-          x <- gsub('\\\\"i', '\u00ef', x, useBytes = TRUE)
-          x <- gsub("\\\\\\^I", '\u00ce', x, useBytes = TRUE)
-          x <- gsub("\\\\\\^i", '\u00ee', x, useBytes = TRUE)
-          x <- gsub("\\\\`I", '\u00cc', x, useBytes = TRUE)
-          x <- gsub("\\\\`i", '\u00ec', x, useBytes = TRUE)
-          Encoding(x) <- 'UTF-8'
-        }
-        x
-    }
-}
-
 collapse <- function(strings){
   paste(strings, collapse = "\n")
 }
@@ -709,9 +677,10 @@ fmtEditor <- function(doc, editor.used.already = FALSE, prefix = NULL, suffix =
 }
 
 fmtJTitle <- function(title){
-  if (grepl('[.?!]$', title, useBytes = TRUE))
-    paste0("\\dQuote{", collapse(cleanupLatex(title)), "}")
-  else paste0("\\dQuote{", collapse(cleanupLatex(title)), "}.")
+  if (!is.null(title))  
+    if (grepl('[.?!]$', title, useBytes = TRUE))
+      paste0("\\dQuote{", collapse(cleanupLatex(title)), "}")
+    else paste0("\\dQuote{", collapse(cleanupLatex(title)), "}.")
 }
 
 fmtVenue <- function(venue){
@@ -1205,7 +1174,7 @@ formatUnpublished <- function(paper){
 }
 
 environment()
-})
+}
 
 # Convert BibEntry object to a fragment of Rd code.
 #
@@ -1226,7 +1195,7 @@ toRd.BibEntry <- function(obj, ...) {
 
   if (is.null(.style)){
     .style <- .BibOptions$bib.style <- 'numeric'
-    style <- MakeBibLaTeX(docstyle = doc.style)
+    style.env <- MakeBibLaTeX(docstyle = doc.style)
   }else if (.style %in% tools::getBibstyle(TRUE)){
     .BibOptions$bib.style <- .style
     style.env <- tools::bibstyle(.style)
